==> ejc-wzxt-api-3.0.0-20230824.020239-156-sources.jar: com/ejianc/business/wzxt/vo/CheckDetailVO.java <==
package com.ejianc.business.wzxt.vo;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 验收明细表
 * 
 * @author generator
 * 
 */
public class CheckDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long checkId; // 验收主键ID
    private java.lang.Long deliveryId; // 发货主键ID
    private java.lang.Long deliveryDetailId; // 发货明细主键ID
    private java.lang.Long orderId; // 订单主键ID
    private java.lang.Long orderDetailId; // 订单明细主键ID
    private java.lang.Long materialId; // 物资主键
    private java.lang.String materialName; // 物资名称
    private java.lang.Long materialTypeId; // 物资类别
    private java.lang.String materialTypeName; // 物资类别名称
    private java.lang.String materialCode; // 物料编码
    private java.lang.String unit; // 单位
    private java.lang.String spec; // 规格型号
    private java.math.BigDecimal deliverNumsSum; // 发货数量
    private java.math.BigDecimal checkNumsSum; // 验收数量
    private java.lang.String materialManufacturer; // 生产厂家
    private java.lang.String memo; // 备注
    private java.lang.String instoreId; // 入库单主键
    private java.lang.String instoreDetailId; // 入库单明细主键
    private java.math.BigDecimal instoreNum; // 入库数量
    private java.lang.String materialSourceId; // 物资来源主键
    private java.lang.Long systemId; // 来源系统
    private java.lang.String materialTypeSourceId; // 物资类别来源主键

    private java.math.BigDecimal checkNumber; //累计验收数量
    private java.math.BigDecimal outStoreNumbers; //累计发货数量
    private java.math.BigDecimal stockNumber; // 可用库存

    private BigDecimal detailCoefficient; // 换算系数
    private BigDecimal detailNetWeight; // 净重
    private BigDecimal detailNetWeightCoefficient; // 单位换算后净重（千克）
    private Integer detailAutomaticWeigh; // 自动称重设置（0：自动称重，1非自动称重）


    public BigDecimal getDetailCoefficient() {
        return detailCoefficient;
    }

    public void setDetailCoefficient(BigDecimal detailCoefficient) {
        this.detailCoefficient = detailCoefficient;
    }

    public BigDecimal getDetailNetWeight() {
        return detailNetWeight;
    }

    public void setDetailNetWeight(BigDecimal detailNetWeight) {
        this.detailNetWeight = detailNetWeight;
    }

    public BigDecimal getDetailNetWeightCoefficient() {
        return detailNetWeightCoefficient;
    }

    public void setDetailNetWeightCoefficient(BigDecimal detailNetWeightCoefficient) {
        this.detailNetWeightCoefficient = detailNetWeightCoefficient;
    }

    public Integer getDetailAutomaticWeigh() {
        return detailAutomaticWeigh;
    }

    public void setDetailAutomaticWeigh(Integer detailAutomaticWeigh) {
        this.detailAutomaticWeigh = detailAutomaticWeigh;
    }

    public BigDecimal getCheckNumber() {
        return checkNumber;
    }

    public void setCheckNumber(BigDecimal checkNumber) {
        this.checkNumber = checkNumber;
    }

    public BigDecimal getOutStoreNumbers() {
        return outStoreNumbers;
    }

    public void setOutStoreNumbers(BigDecimal outStoreNumbers) {
        this.outStoreNumbers = outStoreNumbers;
    }

    public BigDecimal getStockNumber() {
        return stockNumber;
    }

    public void setStockNumber(BigDecimal stockNumber) {
        this.stockNumber = stockNumber;
    }

    public String getMaterialSourceId() {
        return materialSourceId;
    }

    public void setMaterialSourceId(String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }

    public Long getSystemId() {
        return systemId;
    }

    public void setSystemId(Long systemId) {
        this.systemId = systemId;
    }

    public String getMaterialTypeSourceId() {
        return materialTypeSourceId;
    }

    public void setMaterialTypeSourceId(String materialTypeSourceId) {
        this.materialTypeSourceId = materialTypeSourceId;
    }
    

    /**
     * 验收主键ID
     */
    public java.lang.Long getCheckId() {
        return checkId;
    }

    /**
     * 验收主键ID
     */
    public void setCheckId(java.lang.Long checkId) {
        this.checkId = checkId;
    }
    /**
     * 发货主键ID
     */
    public java.lang.Long getDeliveryId() {
        return deliveryId;
    }

    /**
     * 发货主键ID
     */
    public void setDeliveryId(java.lang.Long deliveryId) {
        this.deliveryId = deliveryId;
    }
    /**
     * 发货明细主键ID
     */
    public java.lang.Long getDeliveryDetailId() {
        return deliveryDetailId;
    }

    /**
     * 发货明细主键ID
     */
    public void setDeliveryDetailId(java.lang.Long deliveryDetailId) {
        this.deliveryDetailId = deliveryDetailId;
    }
    /**
     * 订单主键ID
     */
    public java.lang.Long getOrderId() {
        return orderId;
    }

    /**
     * 订单主键ID
     */
    public void setOrderId(java.lang.Long orderId) {
        this.orderId = orderId;
    }
    /**
     * 订单明细主键ID
     */
    public java.lang.Long getOrderDetailId() {
        return orderDetailId;
    }

    /**
     * 订单明细主键ID
     */
    public void setOrderDetailId(java.lang.Long orderDetailId) {
        this.orderDetailId = orderDetailId;
    }
    /**
     * 物资主键
     */
    public java.lang.Long getMaterialId() {
        return materialId;
    }

    /**
     * 物资主键
     */
    public void setMaterialId(java.lang.Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 物资名称
     */
    public java.lang.String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(java.lang.String materialName) {
        this.materialName = materialName;
    }
    /**
     * 物资类别
     */
    public java.lang.Long getMaterialTypeId() {
        return materialTypeId;
    }

    /**
     * 物资类别
     */
    public void setMaterialTypeId(java.lang.Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    /**
     * 物资类别名称
     */
    public java.lang.String getMaterialTypeName() {
        return materialTypeName;
    }

    /**
     * 物资类别名称
     */
    public void setMaterialTypeName(java.lang.String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    /**
     * 物料编码
     */
    public java.lang.String getMaterialCode() {
        return materialCode;
    }

    /**
     * 物料编码
     */
    public void setMaterialCode(java.lang.String materialCode) {
        this.materialCode = materialCode;
    }
    /**
     * 单位
     */
    public java.lang.String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(java.lang.String unit) {
        this.unit = unit;
    }
    /**
     * 规格型号
     */
    public java.lang.String getSpec() {
        return spec;
    }

    /**
     * 规格型号
     */
    public void setSpec(java.lang.String spec) {
        this.spec = spec;
    }
    /**
     * 发货数量
     */
    public java.math.BigDecimal getDeliverNumsSum() {
        return deliverNumsSum;
    }

    /**
     * 发货数量
     */
    public void setDeliverNumsSum(java.math.BigDecimal deliverNumsSum) {
        this.deliverNumsSum = deliverNumsSum;
    }
    /**
     * 验收数量
     */
    public java.math.BigDecimal getCheckNumsSum() {
        return checkNumsSum;
    }

    /**
     * 验收数量
     */
    public void setCheckNumsSum(java.math.BigDecimal checkNumsSum) {
        this.checkNumsSum = checkNumsSum;
    }
    /**
     * 生产厂家
     */
    public java.lang.String getMaterialManufacturer() {
        return materialManufacturer;
    }

    /**
     * 生产厂家
     */
    public void setMaterialManufacturer(java.lang.String materialManufacturer) {
        this.materialManufacturer = materialManufacturer;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 入库单主键
     */
    public java.lang.String getInstoreId() {
        return instoreId;
    }

    /**
     * 入库单主键
     */
    public void setInstoreId(java.lang.String instoreId) {
        this.instoreId = instoreId;
    }
    /**
     * 入库单明细主键
     */
    public java.lang.String getInstoreDetailId() {
        return instoreDetailId;
    }

    /**
     * 入库单明细主键
     */
    public void setInstoreDetailId(java.lang.String instoreDetailId) {
        this.instoreDetailId = instoreDetailId;
    }
    /**
     * 入库数量
     */
    public java.math.BigDecimal getInstoreNum() {
        return instoreNum;
    }

    /**
     * 入库数量
     */
    public void setInstoreNum(java.math.BigDecimal instoreNum) {
        this.instoreNum = instoreNum;
    }
    
}

==> ejc-wzxt-api-3.0.0-20241120.064237-166-sources.jar: com/ejianc/business/wzxt/vo/CheckDetailVO.java <==
package com.ejianc.business.wzxt.vo;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 验收明细表
 * 
 * @author generator
 * 
 */
public class CheckDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long checkId; // 验收主键ID
    private java.lang.Long deliveryId; // 发货主键ID
    private java.lang.Long deliveryDetailId; // 发货明细主键ID
    private java.lang.Long orderId; // 订单主键ID
    private java.lang.Long orderDetailId; // 订单明细主键ID
    private java.lang.Long materialId; // 物资主键
    private java.lang.String materialName; // 物资名称
    private java.lang.Long materialTypeId; // 物资类别
    private java.lang.String materialTypeName; // 物资类别名称
    private java.lang.String materialCode; // 物料编码
    private java.lang.String unit; // 单位
    private java.lang.String spec; // 规格型号
    private java.math.BigDecimal deliverNumsSum; // 发货数量
    private java.math.BigDecimal checkNumsSum; // 验收数量
    private java.lang.String materialManufacturer; // 生产厂家
    private java.lang.String memo; // 备注
    private java.lang.String instoreId; // 入库单主键
    private java.lang.String instoreDetailId; // 入库单明细主键
    private java.math.BigDecimal instoreNum; // 入库数量
    private java.lang.String materialSourceId; // 物资来源主键
    private java.lang.Long systemId; // 来源系统
    private java.lang.String materialTypeSourceId; // 物资类别来源主键

    private java.math.BigDecimal checkNumber; //累计验收数量
    private java.math.BigDecimal outStoreNumbers; //累计发货数量
    private java.math.BigDecimal stockNumber; // 可用库存

    private BigDecimal detailCoefficient; // 换算系数
    private BigDecimal detailNetWeight; // 净重
    private BigDecimal detailNetWeightCoefficient; // 单位换算后净重（千克）
    private Integer detailAutomaticWeigh; // 自动称重设置（0：自动称重，1非自动称重）
    private BigDecimal orderNumsSum; // 订单数量


    public BigDecimal getOrderNumsSum() {
        return orderNumsSum;
    }

    public void setOrderNumsSum(BigDecimal orderNumsSum) {
        this.orderNumsSum = orderNumsSum;
    }

    public BigDecimal getDetailCoefficient() {
        return detailCoefficient;
    }

    public void setDetailCoefficient(BigDecimal detailCoefficient) {
        this.detailCoefficient = detailCoefficient;
    }

    public BigDecimal getDetailNetWeight() {
        return detailNetWeight;
    }

    public void setDetailNetWeight(BigDecimal detailNetWeight) {
        this.detailNetWeight = detailNetWeight;
    }

    public BigDecimal getDetailNetWeightCoefficient() {
        return detailNetWeightCoefficient;
    }

    public void setDetailNetWeightCoefficient(BigDecimal detailNetWeightCoefficient) {
        this.detailNetWeightCoefficient = detailNetWeightCoefficient;
    }

    public Integer getDetailAutomaticWeigh() {
        return detailAutomaticWeigh;
    }

    public void setDetailAutomaticWeigh(Integer detailAutomaticWeigh) {
        this.detailAutomaticWeigh = detailAutomaticWeigh;
    }

    public BigDecimal getCheckNumber() {
        return checkNumber;
    }

    public void setCheckNumber(BigDecimal checkNumber) {
        this.checkNumber = checkNumber;
    }

    public BigDecimal getOutStoreNumbers() {
        return outStoreNumbers;
    }

    public void setOutStoreNumbers(BigDecimal outStoreNumbers) {
        this.outStoreNumbers = outStoreNumbers;
    }

    public BigDecimal getStockNumber() {
        return stockNumber;
    }

    public void setStockNumber(BigDecimal stockNumber) {
        this.stockNumber = stockNumber;
    }

    public String getMaterialSourceId() {
        return materialSourceId;
    }

    public void setMaterialSourceId(String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }

    public Long getSystemId() {
        return systemId;
    }

    public void setSystemId(Long systemId) {
        this.systemId = systemId;
    }

    public String getMaterialTypeSourceId() {
        return materialTypeSourceId;
    }

    public void setMaterialTypeSourceId(String materialTypeSourceId) {
        this.materialTypeSourceId = materialTypeSourceId;
    }
    

    /**
     * 验收主键ID
     */
    public java.lang.Long getCheckId() {
        return checkId;
    }

    /**
     * 验收主键ID
     */
    public void setCheckId(java.lang.Long checkId) {
        this.checkId = checkId;
    }
    /**
     * 发货主键ID
     */
    public java.lang.Long getDeliveryId() {
        return deliveryId;
    }

    /**
     * 发货主键ID
     */
    public void setDeliveryId(java.lang.Long deliveryId) {
        this.deliveryId = deliveryId;
    }
    /**
     * 发货明细主键ID
     */
    public java.lang.Long getDeliveryDetailId() {
        return deliveryDetailId;
    }

    /**
     * 发货明细主键ID
     */
    public void setDeliveryDetailId(java.lang.Long deliveryDetailId) {
        this.deliveryDetailId = deliveryDetailId;
    }
    /**
     * 订单主键ID
     */
    public java.lang.Long getOrderId() {
        return orderId;
    }

    /**
     * 订单主键ID
     */
    public void setOrderId(java.lang.Long orderId) {
        this.orderId = orderId;
    }
    /**
     * 订单明细主键ID
     */
    public java.lang.Long getOrderDetailId() {
        return orderDetailId;
    }

    /**
     * 订单明细主键ID
     */
    public void setOrderDetailId(java.lang.Long orderDetailId) {
        this.orderDetailId = orderDetailId;
    }
    /**
     * 物资主键
     */
    public java.lang.Long getMaterialId() {
        return materialId;
    }

    /**
     * 物资主键
     */
    public void setMaterialId(java.lang.Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 物资名称
     */
    public java.lang.String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(java.lang.String materialName) {
        this.materialName = materialName;
    }
    /**
     * 物资类别
     */
    public java.lang.Long getMaterialTypeId() {
        return materialTypeId;
    }

    /**
     * 物资类别
     */
    public void setMaterialTypeId(java.lang.Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    /**
     * 物资类别名称
     */
    public java.lang.String getMaterialTypeName() {
        return materialTypeName;
    }

    /**
     * 物资类别名称
     */
    public void setMaterialTypeName(java.lang.String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    /**
     * 物料编码
     */
    public java.lang.String getMaterialCode() {
        return materialCode;
    }

    /**
     * 物料编码
     */
    public void setMaterialCode(java.lang.String materialCode) {
        this.materialCode = materialCode;
    }
    /**
     * 单位
     */
    public java.lang.String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(java.lang.String unit) {
        this.unit = unit;
    }
    /**
     * 规格型号
     */
    public java.lang.String getSpec() {
        return spec;
    }

    /**
     * 规格型号
     */
    public void setSpec(java.lang.String spec) {
        this.spec = spec;
    }
    /**
     * 发货数量
     */
    public java.math.BigDecimal getDeliverNumsSum() {
        return deliverNumsSum;
    }

    /**
     * 发货数量
     */
    public void setDeliverNumsSum(java.math.BigDecimal deliverNumsSum) {
        this.deliverNumsSum = deliverNumsSum;
    }
    /**
     * 验收数量
     */
    public java.math.BigDecimal getCheckNumsSum() {
        return checkNumsSum;
    }

    /**
     * 验收数量
     */
    public void setCheckNumsSum(java.math.BigDecimal checkNumsSum) {
        this.checkNumsSum = checkNumsSum;
    }
    /**
     * 生产厂家
     */
    public java.lang.String getMaterialManufacturer() {
        return materialManufacturer;
    }

    /**
     * 生产厂家
     */
    public void setMaterialManufacturer(java.lang.String materialManufacturer) {
        this.materialManufacturer = materialManufacturer;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 入库单主键
     */
    public java.lang.String getInstoreId() {
        return instoreId;
    }

    /**
     * 入库单主键
     */
    public void setInstoreId(java.lang.String instoreId) {
        this.instoreId = instoreId;
    }
    /**
     * 入库单明细主键
     */
    public java.lang.String getInstoreDetailId() {
        return instoreDetailId;
    }

    /**
     * 入库单明细主键
     */
    public void setInstoreDetailId(java.lang.String instoreDetailId) {
        this.instoreDetailId = instoreDetailId;
    }
    /**
     * 入库数量
     */
    public java.math.BigDecimal getInstoreNum() {
        return instoreNum;
    }

    /**
     * 入库数量
     */
    public void setInstoreNum(java.math.BigDecimal instoreNum) {
        this.instoreNum = instoreNum;
    }
    
}
